
## CATO-CLI - query.container.fqdn.searchFqdn:
[Click here](https://api.catonetworks.com/documentation/#query-query.container.fqdn.searchFqdn) for documentation on this operation.

### Usage for query.container.fqdn.searchFqdn:

```bash
catocli query container fqdn searchFqdn -h

catocli query container fqdn searchFqdn <json>

catocli query container fqdn searchFqdn --json-file query.container.fqdn.searchFqdn.json

catocli query container fqdn searchFqdn '{"fqdnContainerSearchFqdnInput":{"fqdn":"example_value"}}'

catocli query container fqdn searchFqdn '{
    "fqdnContainerSearchFqdnInput": {
        "fqdn": "example_value"
    }
}'
```

#### Operation Arguments for query.container.fqdn.searchFqdn ####

`accountId` [ID] - (required) N/A    
`fqdnContainerSearchFqdnInput` [FqdnContainerSearchFqdnInput] - (required) N/A    
